==> haskell-torrent-10000.1.3-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-E1ys094Fne98G6L7my5Rzd
key:                  torrent-10000.1.3-E1ys094Fne98G6L7my5Rzd
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  aa3e42ab70171009828f78907fdb7a84
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-E1ys094Fne98G6L7my5Rzd
depends:
    base-4.17.2.1 bencode-0.6.1.1-E2qi9VU0Qk3D1fAYCwJab9 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    syb-0.7.2.4-7rM6H2Cx7RdIPDVFkspy8A

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.3-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-35srtptgcxD2QGo3Up1lnQ
key:                  torrent-10000.1.3-35srtptgcxD2QGo3Up1lnQ
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  ddd7d066489921c5d711e2a59c6cb673
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-35srtptgcxD2QGo3Up1lnQ
depends:
    base-4.17.2.1 bencode-0.6.1.1-BIwx1BskxGf60KLygRHQJ8 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    syb-0.7.2.4-BoBt6NiEdTQJ1wn7K7eKAO

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
